@@ -29,8 +29,9 @@
  *   and things like ncurses libmenu are not worth the storage overhead.
  *
  */
-/* Why is this needed? Segfaults without it */
-#include <netinet/in.h>
+#include <ncurses.h>
+#include <panel.h>
+#include <stdint.h>
 
 #include "nwipe.h"
 #include "context.h"
@@ -125,7 +126,7 @@ const char* stats_title = " Statistics ";
 
 /* Footer labels. */
 const char* nwipe_buttons1 = "Ctrl-C=Quit S=Start M=Method P=PRNG V=Verify R=Rounds B=Blanking-pass Space=Select";
-const char* nwipe_buttons2 = " J=Up K=Down Space=Select";
+const char* nwipe_buttons2 = " J=Down K=Up Space=Select";
 const char* nwipe_buttons3 = " B=Blank screen, ctrl-c=Quit";
 
 
@@ -139,6 +140,7 @@ void nwipe_gui_title( WINDOW* w, const char* s )
 
 	/* The number of lines in the window. (Not used.) */
 	int wy;
+	(void) wy; /* flag wy not used to the compiler, to silence warning */
 
 	/* The number of columns in the window. */
 	int wx;
@@ -450,7 +452,7 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 					wprintw( main_window, " [wipe] %i. %s - %s %s (%s)", (i + offset + 1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
-										c[i+offset]->identity.serial_no,
+										c[i+offset]->serial_no,
 										c[i+offset]->device_size_text );
 					break;
 
@@ -459,7 +461,7 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 					wprintw( main_window, " [    ] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
-										c[i+offset]->identity.serial_no,
+										c[i+offset]->serial_no,
 										c[i+offset]->device_size_text );
 					break;
 
@@ -469,7 +471,7 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 					wprintw( main_window, " [****] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
-										c[i+offset]->identity.serial_no,
+										c[i+offset]->serial_no,
 										c[i+offset]->device_size_text );
 					break;
 
@@ -479,7 +481,7 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 					wprintw( main_window, " [----] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
-										c[i+offset]->identity.serial_no,
+										c[i+offset]->serial_no,
 										c[i+offset]->device_size_text );
 					break;
 
@@ -995,7 +997,7 @@ void nwipe_gui_prng( void )
 	if( nwipe_options.prng == &nwipe_isaac   ) { focus = 1; }
 
 
-	while( keystroke != ERR )
+	do
 	{
 		/* Clear the main window. */
 		werase( main_window );
@@ -1085,7 +1087,8 @@ void nwipe_gui_prng( void )
 
 		} /* switch */
 		
-	} /* while */
+	}
+	while( keystroke != ERR );
 
 } /* nwipe_gui_prng */
 
@@ -1124,7 +1127,7 @@ void nwipe_gui_verify( void )
 	nwipe_gui_title( footer_window, nwipe_buttons2 );
 	wrefresh( footer_window );
 
-	while( keystroke != ERR )
+	do
 	{
 		/* Clear the main window. */
 		werase( main_window );
@@ -1219,7 +1222,8 @@ void nwipe_gui_verify( void )
 
 		} /* switch */
 		
-	} /* while */
+	}
+	while( keystroke != ERR );
 
 } /* nwipe_gui_verify */
 
@@ -1257,7 +1261,7 @@ void nwipe_gui_noblank( void )
 	nwipe_gui_title( footer_window, nwipe_buttons2 );
 	wrefresh( footer_window );
 
-	while( keystroke != ERR )
+	do	
 	{
 		/* Clear the main window. */
 		werase( main_window );
@@ -1339,8 +1343,9 @@ void nwipe_gui_noblank( void )
 
 		} /* switch */
 		
-	} /* while */
+	}
 
+	while( keystroke != ERR );
 } /* nwipe_gui_noblank */
 
 
@@ -1812,11 +1817,11 @@ void *nwipe_gui_status( void *ptr )
 			for( i = offset ; i < offset + slots && i < count ; i++ )
 			{
 				/* Print the context label. */
-				if ( strlen(c[i]->identity.serial_no) )
+				if ( strlen((const char*)c[i]->serial_no) )	
 				{
 					mvwprintw( main_window, yy++, 2, "%s - %s (%s)", c[i]->device_name,
 												c[i]->label,
-												c[i]->identity.serial_no);
+												c[i]->serial_no);
 				}
 				else {
 					mvwprintw( main_window, yy++, 2, "%s - %s", c[i]->device_name,
