@@ -22,6 +22,9 @@
 #ifndef LOGGING_H_
 #define LOGGING_H_
 
+/* Maximum size a log message can be */
+#define MAX_LOG_LINE_CHARS 512
+
 typedef enum nwipe_log_t_
 {
 	NWIPE_LOG_NONE = 0,
@@ -36,6 +39,7 @@ typedef enum nwipe_log_t_
 
 void nwipe_log( nwipe_log_t level, const char* format, ... );
 void nwipe_perror( int nwipe_errno, const char* f, const char* s );
+int nwipe_log_sysinfo();
 
 /* Global array to hold log values to print when logging to STDOUT */
 //extern char **log_lines;
