@@ -20,10 +20,14 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  *
  */
+#define _POSIX_SOURCE
 
-#include <netinet/in.h>
+#include <stdint.h>
 #include <time.h>
 #include <signal.h>
+#include <pthread.h>
+#include <bits/pthreadtypes.h>
+#include <bits/sigthread.h>
 
 #include "nwipe.h"
 #include "context.h"
@@ -48,7 +52,7 @@ int main( int argc, char** argv )
         int nwipe_enumerated;          /* The number of contexts that have been enumerated. */
         int nwipe_error = 0;           /* An error counter.                                 */
         int nwipe_selected = 0;        /* The number of contexts that have been selected.   */
-        pthread_t nwipe_gui_thread;    /* The thread ID of the GUI thread.                  */
+        pthread_t nwipe_gui_thread = 0;    /* The thread ID of the GUI thread.                  */
         pthread_t nwipe_sigint_thread; /* The thread ID of the sigint handler.              */
 
         /* The entropy source file handle. */
@@ -98,10 +102,14 @@ int main( int argc, char** argv )
                 nwipe_enumerated = nwipe_device_get( &c1, argv, argc );
                 if ( nwipe_enumerated == 0 )
                 {
+                    cleanup();
                     exit(1);
                 }
 
         }
+        
+        /* Log the System information */
+        nwipe_log_sysinfo();
 
 
         /* The array of pointers to contexts that will actually be wiped. */
@@ -142,6 +150,7 @@ int main( int argc, char** argv )
         
         nwipe_thread_data_ptr.c = c2;
         nwipe_misc_thread_data.nwipe_enumerated = nwipe_enumerated;
+        nwipe_misc_thread_data.nwipe_selected = 0;
         if( !nwipe_options.nogui )
                 nwipe_misc_thread_data.gui_thread = &nwipe_gui_thread;
         nwipe_thread_data_ptr.nwipe_misc_thread_data = &nwipe_misc_thread_data;
@@ -205,6 +214,7 @@ int main( int argc, char** argv )
                 if( nwipe_options.nogui )
                 {
                         printf("--nogui option must be used with autonuke option\n"); 
+                        cleanup();
                         exit(1);
                 }
                 else
@@ -286,8 +296,8 @@ int main( int argc, char** argv )
                 */
 
                 /* Print serial number of device if it exists. */
-                if ( strlen(c2[i]->identity.serial_no) ) {
-                        nwipe_log( NWIPE_LOG_INFO, "Device %s has serial number %s", c2[i]->device_name, c2[i]->identity.serial_no);
+		if ( strlen((const char*)c2[i]->serial_no) ) {
+                        nwipe_log( NWIPE_LOG_INFO, "Device %s has serial number %s", c2[i]->device_name, c2[i]->serial_no);
                 }
                 
 
@@ -476,6 +486,8 @@ int main( int argc, char** argv )
                 printf("%s\n", log_lines[i]);
         }
 
+        cleanup();
+
         /* Success. */
         return 0;
 
@@ -566,12 +578,14 @@ void *signal_hand(void *ptr)
                         case SIGQUIT :
                         case SIGTERM :
                         {
+                                nwipe_log( NWIPE_LOG_INFO, "nwipe_selected = %lu", nwipe_misc_thread_data->nwipe_selected );
 
                                 for( i = 0; i < nwipe_misc_thread_data->nwipe_selected; i++ )
                                 {
 
                                         if ( c[i]->thread )
                                         {
+                                                nwipe_log( NWIPE_LOG_INFO, "Cancelling thread for %s", c[i]->device_name );
                                                 pthread_cancel( c[i]->thread );
                                         }
                                 }
@@ -579,7 +593,7 @@ void *signal_hand(void *ptr)
                                 // Kill the GUI thread
                                 if( !nwipe_options.nogui )
                                 {
-                                        if ( nwipe_misc_thread_data->gui_thread )
+                                        if ( *nwipe_misc_thread_data->gui_thread )
                                         {
                                                 pthread_cancel( *nwipe_misc_thread_data->gui_thread );
                                                 *nwipe_misc_thread_data->gui_thread = 0;
@@ -597,8 +611,7 @@ void *signal_hand(void *ptr)
 
                                 printf("Program interrupted (caught signal %d)\n", sig); 
 
-                                // Cleanup
-                                // TODO: All other cleanup required
+                                cleanup();
 
                                 exit(0);
 
@@ -612,5 +625,20 @@ void *signal_hand(void *ptr)
 
 } /* end of signal_hand */
 
+int cleanup()
+{
+	/* Deallocate memory used by logging */
+	int idx;
+	for ( idx=0; idx < log_elements_allocated; idx++ )
+	{
+		free ( log_lines[idx] );
+	}
+	log_elements_allocated=0; /* zeroed just in case cleanup is called twice */
+	free ( log_lines );
+	
+	/* TODO: All other cleanup required */
+	
+	return 0;
+}
  
 /* eof */
