@@ -20,9 +20,13 @@
  *
  */
 
+
 #ifndef NWIPE_H_
 #define NWIPE_H_
 
+/* Function prototypes */
+int cleanup();
+
 #ifndef _LARGEFILE64_SOURCE
 #define _LARGEFILE64_SOURCE
 #endif
@@ -33,7 +37,11 @@
 
 /* workaround for Fedora */
 #ifndef off64_t
-# define off64_t off_t
+#ifndef off_t
+#define off64_t int64_t
+#else
+#define off64_t off_t
+#endif
 #endif
 
 /* Busybox headers. */
